@@ -3,6 +3,7 @@
 #' Passing in a download object the function outputs a Bacon or Clam formatted file to a
 #' user defined destination for age modelling with existing age-depth modeling software.
 #'
+#' @importFrom utils write.csv write.table
 #' @param download A single site returned by \code{get_download}.
 #' @param chronology Default is \code{1}, the default chronology for the core.  If a core has more than one chronology the user can define a different set of chronological controls.
 #' @param path The location of the 'Cores' folder & working directory for Bacon.  Do not include "Cores" in the path name.
@@ -16,6 +17,7 @@
 #' @examples \dontrun{
 #' #  The point of pulling chronology tables is to re-build or examine the chronological 
 #' #  information that was used to build the age-depth model for the core.
+#' 
 #' }
 #' @references
 #' Neotoma Project Website: http://www.neotomadb.org
@@ -52,38 +54,58 @@ write_agefile <- function(download, chronology = 1, path,
     if (!tolower(cal.prog) %in% c('bacon', 'clam')){
       stop('You must define either Bacon or Clam as your model output.')
     }
+    
     if (cal.prog == 'Bacon'){
+      # If you're outputting to the Bacon family of models:
       chron <- data.frame(labid = paste0(chron.controls$chron.control$control.type, 
                                          "_",
                                          chron.controls$chron.control$chron.control.id),
-                          age = chron.controls$chron.control$age,
+                          age   = chron.controls$chron.control$age,
                           error = abs(chron.controls$chron.control$age - 
                                         chron.controls$chron.control$age.young),
                           depth = chron.controls$chron.control$depth,
-                          cc = ifelse(chron.controls$chron.control$control.type %in% uncal,
-                                      1, 0), stringsAsFactors=FALSE)
+                          cc    = ifelse(chron.controls$chron.control$control.type %in% uncal,
+                                         1, 0), stringsAsFactors=FALSE)
+      
       chron$labid[regexpr(',', chron$labid)>0] <- gsub(',', replacement='_', chron$labid[regexpr(',', chron$labid)>0])
     }
+    
     if (cal.prog == 'Clam'){
-      chron <- data.frame(ID = paste0(chron.controls$chron.control$control.type, 
-                                      "_",
-                                     chron.controls$chron.control$chron.control.id),
-                          C14_age = chron.controls$chron.control$age,
-                          cal_BP = chron.controls$chron.control$age,
-                          error = abs(chron.controls$chron.control$age - 
-                                        chron.controls$chron.control$age.young),
-                          offset = NA,
-                          depth = chron.controls$chron.control$depth,
+      #  If you're using Clam:
+      chron <- data.frame(ID        = paste0(chron.controls$chron.control$control.type, 
+                                             "_",
+                                             chron.controls$chron.control$chron.control.id),
+                          C14_age   = chron.controls$chron.control$age,
+                          cal_BP    = chron.controls$chron.control$age,
+                          error     = abs(chron.controls$chron.control$age - 
+                                          chron.controls$chron.control$age.young),
+                          offset    = NA,
+                          depth     = chron.controls$chron.control$depth,
                           thickness = chron.controls$chron.control$thickness,
                           stringsAsFactors=FALSE)
+      
       chron$cal_BP [ chron.controls$chron.control$control.type %in% uncal] <- NA
       chron$C14_age[!chron.controls$chron.control$control.type %in% uncal] <- NA
       
       chron$ID[regexpr(',', chron$labid)>0] <- gsub(',', replacement='_', chron$labid[regexpr(',', chron$labid)>0])
     }
-      
-    depths <- download$sample.meta$depths
+
+    depths <- download$sample.meta$depth
     
+    #  There are a couple checks we need:
+    if(any(regexpr('Core top', chron[,1])>0)){
+      # Core tops need to have error added:
+      if(any(is.na(chron$error[which(regexpr('Core top', chron[,1])>0)]))){
+        warning('Core tops have no error.  By default we are setting the error to 2 yrs.')
+        chron$error[which(regexpr('Core top', chron[,1])>0) & is.na(chron$error)] <- 2
+      }
+    }
+
+    if(any(is.na(chron[,1]))){
+      warning('Some samples in this chronology have no dates.  These samples are being removed.')
+    }
+    
+    #  Now lets make sure the file path is there:
     if (!corename %in% list.files(paste0(path, '/Cores'))){
       works <- dir.create(path = paste0(path, '/Cores/', corename))
       if (!works) {
@@ -92,9 +114,9 @@ write_agefile <- function(download, chronology = 1, path,
       }
     }
     
-    write.csv(chron, paste0(path, '/Cores/', corename, '/', corename, '.csv'),
+    utils::write.csv(chron, paste0(path, '/Cores/', corename, '/', corename, '.csv'),
               row.names = FALSE, quote = TRUE)
-    write.table(depths, paste0(path, '/Cores/', corename, '/', corename, '_depths.txt'),
+    utils::write.table(depths, paste0(path, '/Cores/', corename, '/', corename, '_depths.txt'),
               row.names = FALSE, quote = TRUE,col.names=FALSE)
   }
 }
